@@ -1,11 +1,12 @@
-// Copyright 2008-2022 David Robillard <d@drobilla.net>
+// Copyright 2008-2025 David Robillard <d@drobilla.net>
 // SPDX-License-Identifier: ISC
 
 #include "lv2_evbuf.h"
 #include "jalv_config.h"
 
-#include "lv2/atom/atom.h"
-#include "lv2/atom/util.h"
+#include <lv2/atom/atom.h>
+#include <lv2/atom/util.h>
+#include <zix/attributes.h>
 
 #include <assert.h>
 #include <stdlib.h>
@@ -50,10 +51,12 @@ lv2_evbuf_new(uint32_t capacity, uint32_t atom_Chunk, uint32_t atom_Sequence)
 void
 lv2_evbuf_free(LV2_Evbuf* evbuf)
 {
-  free(evbuf);
+  if (evbuf) {
+    free(evbuf);
+  }
 }
 
-void
+ZIX_REALTIME void
 lv2_evbuf_reset(LV2_Evbuf* evbuf, bool input)
 {
   if (input) {
@@ -65,8 +68,8 @@ lv2_evbuf_reset(LV2_Evbuf* evbuf, bool input)
   }
 }
 
-uint32_t
-lv2_evbuf_get_size(LV2_Evbuf* evbuf)
+ZIX_REALTIME uint32_t
+lv2_evbuf_get_size(const LV2_Evbuf* evbuf)
 {
   assert(evbuf->buf.atom.type != evbuf->atom_Sequence ||
          evbuf->buf.atom.size >= sizeof(LV2_Atom_Sequence_Body));
@@ -75,20 +78,26 @@ lv2_evbuf_get_size(LV2_Evbuf* evbuf)
            : 0;
 }
 
-void*
+ZIX_REALTIME uint32_t
+lv2_evbuf_get_capacity(const LV2_Evbuf* evbuf)
+{
+  return evbuf->capacity;
+}
+
+ZIX_REALTIME void*
 lv2_evbuf_get_buffer(LV2_Evbuf* evbuf)
 {
   return &evbuf->buf;
 }
 
-LV2_Evbuf_Iterator
+ZIX_REALTIME LV2_Evbuf_Iterator
 lv2_evbuf_begin(LV2_Evbuf* evbuf)
 {
   LV2_Evbuf_Iterator iter = {evbuf, 0};
   return iter;
 }
 
-LV2_Evbuf_Iterator
+ZIX_REALTIME LV2_Evbuf_Iterator
 lv2_evbuf_end(LV2_Evbuf* evbuf)
 {
   const uint32_t           size = lv2_evbuf_get_size(evbuf);
@@ -96,13 +105,13 @@ lv2_evbuf_end(LV2_Evbuf* evbuf)
   return iter;
 }
 
-bool
+ZIX_REALTIME bool
 lv2_evbuf_is_valid(LV2_Evbuf_Iterator iter)
 {
   return iter.offset < lv2_evbuf_get_size(iter.evbuf);
 }
 
-LV2_Evbuf_Iterator
+ZIX_REALTIME LV2_Evbuf_Iterator
 lv2_evbuf_next(const LV2_Evbuf_Iterator iter)
 {
   if (!lv2_evbuf_is_valid(iter)) {
@@ -110,9 +119,8 @@ lv2_evbuf_next(const LV2_Evbuf_Iterator iter)
   }
 
   LV2_Atom_Sequence* aseq = &iter.evbuf->buf;
-  LV2_Atom_Event*    aev =
-    (LV2_Atom_Event*)((char*)LV2_ATOM_CONTENTS(LV2_Atom_Sequence, aseq) +
-                      iter.offset);
+  const char* abuf = (const char*)LV2_ATOM_CONTENTS(LV2_Atom_Sequence, aseq);
+  const LV2_Atom_Event* aev = (const LV2_Atom_Event*)(abuf + iter.offset);
 
   const uint32_t offset =
     iter.offset + lv2_atom_pad_size(sizeof(LV2_Atom_Event) + aev->body.size);
@@ -121,7 +129,7 @@ lv2_evbuf_next(const LV2_Evbuf_Iterator iter)
   return next;
 }
 
-bool
+ZIX_REALTIME bool
 lv2_evbuf_get(LV2_Evbuf_Iterator iter,
               uint32_t*          frames,
               uint32_t*          subframes,
@@ -150,7 +158,7 @@ lv2_evbuf_get(LV2_Evbuf_Iterator iter,
   return true;
 }
 
-bool
+ZIX_REALTIME bool
 lv2_evbuf_write(LV2_Evbuf_Iterator* iter,
                 uint32_t            frames,
                 uint32_t            subframes,
